@@ -57,19 +57,26 @@ sub initialize {
 	# create individuals 
 	my @individuals;
 	for my $i ( 1 .. $args{'individual_count'} ) {
-		push @individuals, $fac->create_individual;
+		push @individuals, $fac->create_individual( 'experiment' => $self );
 		
-		# create chromosomes
+		# create chromosomes in homologous pairs
 		my @chromosomes;
 		for my $j ( 1 .. $args{'chromosome_count'} ) {
-			push @chromosomes, $fac->create_chromosome( 'number' => $j );
+			for ( 1 .. 2 ) {
+				push @chromosomes, $fac->create_chromosome( 
+					'number'     => $j,
+					'experiment' => $self,
+				);
 			
-			# create genes
-			my @genes;
-			for my $k ( 1 .. $args{'gene_count'} ) {
-				push @genes, $fac->create_gene;
+				# create genes
+				my @genes;
+				for my $k ( 1 .. $args{'gene_count'} ) {
+					push @genes, $fac->create_gene(
+						'experiment' => $self,
+					);
+				}
+				$chromosomes[-1]->genes(@genes);
 			}
-			$chromosomes[-1]->genes(@genes);
 		}
 		$individuals[-1]->chromosomes(@chromosomes);
 	}
@@ -84,7 +91,6 @@ generation.
 
 =cut
 
-# probably the expected t+1 value
 sub optimum {
 	my ( $self, $gen ) = @_;
 	# do something with env and generation
@@ -177,7 +183,7 @@ Getter and setter for the L<Algorithm::Genetic::Diploid::Population> object
 sub population {
 	my $self = shift;
 	if ( @_ ) {
-		$log->info("assigning new population: @_");
+		$log->debug("assigning new population: @_");
 		$self->{'population'} = shift;
 	}
 	return $self->{'population'};
@@ -225,4 +231,4 @@ sub genecount {
 
 =cut
 
-1;
\ No newline at end of file
+1;
